'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LocaleProviderContext = undefined;

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _translateMaker = require('translate-maker');

var _translateMaker2 = _interopRequireDefault(_translateMaker);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const LocaleProviderContext = exports.LocaleProviderContext = (0, _react.createContext)({});

class LocaleProvider extends _react.Component {

  constructor(props) {
    super(props);

    this.t = (path, attrs, defaultValue) => this.get(path, attrs, defaultValue);

    this.dataChanged = () => {
      this.forceUpdate();
    };

    this.localeChanged = () => {
      this.forceUpdate();
    };

    const {
      translate, locale, namespace, children, controlled } = props,
          rest = (0, _objectWithoutProperties3.default)(props, ['translate', 'locale', 'namespace', 'children', 'controlled']);

    const instance = translate || new _translateMaker2.default(rest);

    this.state = {
      translate: instance
    };

    if (locale) {
      instance.setLocale(locale, namespace);
    }
  }

  componentDidMount() {
    const { translate } = this.state;

    translate.on('locale', this.localeChanged);
    translate.on('changed', this.dataChanged);
  }

  componentWillReceiveProps(newProps) {
    const { locale, namespace } = this.props;
    const { translate } = this.state;

    if (newProps.controlled) {
      if (newProps.locale !== locale) {
        translate.setLocale(newProps.locale, newProps.namespace);
      } else if (newProps.locale && newProps.namespace !== namespace) {
        translate.setLocale(newProps.locale, newProps.namespace);
      }
    }
  }

  componentWillUnmount() {
    const { translate } = this.state;

    translate.removeListener('locale', this.localeChanged);
    translate.removeListener('changed', this.dataChanged);
  }

  getLocale() {
    const { translate } = this.state;
    return translate.getLocale();
  }

  setLocale(locale) {
    var _this = this;

    return (0, _asyncToGenerator3.default)(function* () {
      const { controlled } = _this.props;
      if (controlled) {
        throw new Error('LocaleProvider is set as controlled component. If you want to use setLocale please set controlled = false');
      }

      const { translate } = _this.state;
      yield translate.setLocale(locale);
    })();
  }

  get(path, attrs, defaultValue) {
    const { translate } = this.state;
    return translate.get(path, attrs, defaultValue);
  }

  set(path, value) {
    const { translate } = this.state;
    return translate.set(path, value);
  }

  render() {
    const { children } = this.props;

    return _react2.default.createElement(
      LocaleProviderContext.Provider,
      { value: { localeProvider: this } },
      children
    );
  }
}
exports.default = LocaleProvider;
LocaleProvider.defaultProps = {
  controlled: true
  /*
  locale: undefined,
  namespace: undefined,
  locales: undefined,
  cache: undefined,
  data: undefined,
  adapter: undefined,
  dotNotation: undefined,
  mode: undefined,
  references: undefined,
  variables: undefined,
  combinations: undefined,
  filters: undefined,
  translate: undefined,
  */
};
//# sourceMappingURL=LocaleProvider.js.map