'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

exports.prepareParams = prepareParams;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _server = require('react-dom/server');

var _LocaleProvider = require('./LocaleProvider');

var _LocaleProvider2 = _interopRequireDefault(_LocaleProvider);

var _Namespace = require('./Namespace');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function prepareParams(params, localeProvider) {
  const newParams = {};
  let changed = false;

  Object.keys(params).forEach(key => {
    const value = params[key];
    const isReactElement = (0, _react.isValidElement)(value);
    if (!isReactElement) {
      newParams[key] = value;
    } else {
      changed = true;

      const _localeProvider$props = localeProvider.props,
            { children, locale } = _localeProvider$props,
            rest = (0, _objectWithoutProperties3.default)(_localeProvider$props, ['children', 'locale']);

      newParams[key] = (0, _server.renderToStaticMarkup)(_react2.default.createElement(
        _LocaleProvider2.default,
        rest,
        value
      ));
    }
  });

  return changed ? newParams : params;
}

class Translate extends _react.Component {

  getPath() {
    const { path, $namespace } = this.props;
    if (!$namespace) {
      return path;
    }

    const parentPath = $namespace.getPath();
    if (!parentPath) {
      return path;
    }

    return `${parentPath}.${path}`;
  }

  render() {
    const _props = this.props,
          {
      path,
      $namespace,
      $localeProvider,
      defaultValue,
      params,
      children,
      html
    } = _props,
          rest = (0, _objectWithoutProperties3.default)(_props, ['path', '$namespace', '$localeProvider', 'defaultValue', 'params', 'children', 'html']);

    const updatedDefaultValue = !defaultValue && typeof children !== 'function' ? children : defaultValue;

    const updatedParams = prepareParams(params || rest, $localeProvider);
    const text = $localeProvider.get(this.getPath(), updatedParams, updatedDefaultValue);

    if (typeof children === 'function') {
      return children(text);
    }

    if (html) {
      return _react2.default.createElement('span', {
        dangerouslySetInnerHTML: {
          __html: text
        }
      });
    }

    return text;
  }
}

Translate.defaultProps = {
  defaultValue: undefined,
  description: undefined,
  params: undefined,
  children: undefined,
  $namespace: undefined,
  html: false
};
exports.default = (0, _react.forwardRef)((props, ref) => _react2.default.createElement(
  _LocaleProvider.LocaleProviderContext.Consumer,
  null,
  ({ localeProvider }) => _react2.default.createElement(
    _Namespace.NamespaceContext.Consumer,
    null,
    ({ namespace }) => _react2.default.createElement(Translate, (0, _extends3.default)({}, props, {
      $localeProvider: localeProvider,
      $namespace: namespace,
      ref: ref
    }))
  )
));
//# sourceMappingURL=Translate.js.map