'use strict';

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _translateMaker = require('translate-maker');

var _translateMaker2 = _interopRequireDefault(_translateMaker);

var _enzyme = require('enzyme');

var _index = require('./index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Translate', function () {
  it('should be able to create simple instance', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  test: 'Test response'
                }
              }
            });
            _context.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'test' })
            ));


            expect(wrapper.text()).toBe('Test response');

          case 5:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));

  it('should be able to create simple instance with default value', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _index.LocaleProvider,
      { locale: 'sk_SK' },
      _react2.default.createElement(_index2.default, { path: 'test', defaultValue: 'Default value' })
    ));

    expect(wrapper.text()).toBe('Default value');
  });

  it('should be able to create simple instance with default value as children', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _index.LocaleProvider,
      { locale: 'sk_SK' },
      _react2.default.createElement(
        _index2.default,
        { path: 'test' },
        'Default value'
      )
    ));

    expect(wrapper.text()).toBe('Default value');
  });

  it('should be able to create element h1', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  test: 'Test response'
                }
              }
            });
            _context2.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(
                'h1',
                null,
                _react2.default.createElement(_index2.default, { path: 'test', defaultValue: 'Default value' })
              )
            ));


            expect(wrapper.html()).toBe('<h1>Test response</h1>');

          case 5:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined);
  })));

  it('should be able to use variable inside translation', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee3() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  hello: 'Hello {$name}'
                }
              }
            });
            _context3.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'hello', name: 'Zlatko' })
            ));


            expect(wrapper.text()).toBe('Hello Zlatko');

          case 5:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined);
  })));

  it('should be able to use plurals inside translation', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee4() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  followers: '{$name} has {$followers, plural,\n            =0 {no followers}\n            =1 {# follower}\n               {# followers}\n          }'
                }
              }
            });
            _context4.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'followers', name: 'Zlatko', followers: 0 })
            ));


            expect(wrapper.text()).toBe('Zlatko has no followers');

          case 5:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined);
  })));

  it('should be able to use params instead of props', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee5() {
    var translate, user, wrapper;
    return _regenerator2.default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  hello: 'Hello {$name}'
                }
              }
            });
            _context5.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            user = {
              name: 'Zlatko'
            };
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'hello', params: user })
            ));


            expect(wrapper.text()).toBe('Hello Zlatko');

          case 6:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined);
  })));

  it('should be able to use html content', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee6() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  hello: 'Welcome back <b>{$name}</b>. How is it going?'
                }
              }
            });
            _context6.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'hello', name: 'Zlatko', html: true })
            ));


            expect(wrapper.html()).toBe('<span>Welcome back <b>Zlatko</b>. How is it going?</span>');

          case 5:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined);
  })));

  it('should be able to use filters', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee7() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  hello: 'Hello {$name | star}'
                }
              },
              filters: {
                star: function star(value) {
                  return '*** ' + value + ' ***';
                }
              }
            });
            _context7.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'hello', name: 'Zlatko' })
            ));


            expect(wrapper.text()).toBe('Hello *** Zlatko ***');

          case 5:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, undefined);
  })));

  it('should be able to use namespace', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee8() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  namespace: {
                    test: 'Test response'
                  }
                }
              }
            });
            _context8.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(
                _index.Namespace,
                { path: 'namespace' },
                _react2.default.createElement(_index2.default, { path: 'test' })
              )
            ));


            expect(wrapper.text()).toBe('Test response');

          case 5:
          case 'end':
            return _context8.stop();
        }
      }
    }, _callee8, undefined);
  })));

  it('should be able to change namespace', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee9() {
    var translate, Main, wrapper;
    return _regenerator2.default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  namespace1: {
                    test: 'Test response'
                  },
                  namespace2: {
                    test: 'Test response2'
                  }
                }
              }
            });
            _context9.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            Main = function Main(_ref10) {
              var namespace = _ref10.namespace;
              return _react2.default.createElement(
                _index.LocaleProvider,
                { locale: 'sk_SK', translate: translate },
                _react2.default.createElement(
                  _index.Namespace,
                  { path: namespace },
                  _react2.default.createElement(_index2.default, { path: 'test' })
                )
              );
            };

            wrapper = (0, _enzyme.mount)(_react2.default.createElement(Main, { namespace: 'namespace1' }));

            expect(wrapper.text()).toBe('Test response');

            wrapper.setProps({ namespace: 'namespace2' });
            expect(wrapper.text()).toBe('Test response2');

          case 8:
          case 'end':
            return _context9.stop();
        }
      }
    }, _callee9, undefined);
  })));

  it('should be able to use namespace inside namespace', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee10() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  namespace1: {
                    namespace2: {
                      test: 'Test response'
                    }
                  }
                }
              }
            });
            _context10.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(
                _index.Namespace,
                { path: 'namespace1' },
                _react2.default.createElement(
                  _index.Namespace,
                  { path: 'namespace2', compose: true },
                  _react2.default.createElement(_index2.default, { path: 'test' })
                )
              )
            ));


            expect(wrapper.text()).toBe('Test response');

          case 5:
          case 'end':
            return _context10.stop();
        }
      }
    }, _callee10, undefined);
  })));

  it('should be able to use namespace inside namespace with replace', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee11() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  namespace: {
                    test: 'Test response'
                  }
                }
              }
            });
            _context11.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(
                _index.Namespace,
                { path: 'namespace1' },
                _react2.default.createElement(
                  _index.Namespace,
                  { path: 'namespace' },
                  _react2.default.createElement(_index2.default, { path: 'test' })
                )
              )
            ));


            expect(wrapper.text()).toBe('Test response');

          case 5:
          case 'end':
            return _context11.stop();
        }
      }
    }, _callee11, undefined);
  })));

  it('should be able to use LocaleSwitch as uncontrolled component', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee12() {
    var data, translate, changeLocale, wrapper;
    return _regenerator2.default.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            data = {
              sk_SK: {
                test: 'Testovacia odpoved'
              },
              en_US: {
                test: 'Test response'
              }
            };
            translate = new _translateMaker2.default({
              data: data
            });
            _context12.next = 4;
            return translate.setLocale('sk_SK');

          case 4:
            changeLocale = void 0;
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { data: data, locale: 'sk_SK', translate: translate, controlled: false },
              _react2.default.createElement(
                'div',
                null,
                _react2.default.createElement(
                  'span',
                  null,
                  _react2.default.createElement(_index2.default, { path: 'test' })
                ),
                _react2.default.createElement(
                  _index.LocaleSwitch,
                  {
                    onError: function onError(err) {
                      throw err;
                    }
                  },
                  function (props) {
                    changeLocale = props.changeLocale;
                    return null;
                  }
                )
              )
            ));


            expect(wrapper.text()).toBe('Testovacia odpoved');

            _context12.next = 9;
            return changeLocale('en_US');

          case 9:

            expect(wrapper.text()).toBe('Test response');

          case 10:
          case 'end':
            return _context12.stop();
        }
      }
    }, _callee12, undefined);
  })));

  it('should be able to use LocaleSwitch as uncontrolled component', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee13() {
    var translate;
    return _regenerator2.default.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  test: 'Testovacia odpoved'
                },
                en_US: {
                  test: 'Test response'
                }
              }
            });
            _context13.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            return _context13.abrupt('return', new Promise(function (resolve, reject) {
              var wrapper = void 0;

              function handleLocaleChange(newLocale) {
                expect(newLocale).toBe('en_US');
                expect(wrapper.find('span').html()).toBe('<span>Test response</span>');
                resolve();
              }

              var onChange = void 0;

              var Main = function Main() {
                return _react2.default.createElement(
                  _index.LocaleProvider,
                  { translate: translate, controlled: false },
                  _react2.default.createElement(
                    'div',
                    null,
                    _react2.default.createElement(
                      'span',
                      null,
                      _react2.default.createElement(_index2.default, { path: 'test' })
                    ),
                    _react2.default.createElement(
                      _index.LocaleSwitch,
                      {
                        onChange: handleLocaleChange,
                        onError: reject
                      },
                      function (_ref15) {
                        var changeLocale = _ref15.changeLocale;

                        onChange = changeLocale;
                        return null;
                      }
                    )
                  )
                );
              };

              wrapper = (0, _enzyme.mount)(_react2.default.createElement(Main, null));

              expect(wrapper.find('span').html()).toBe('<span>Testovacia odpoved</span>');

              onChange('en_US');
              // wrapper.find('select').simulate('change', {target: { value : 'en_US'}});
            }));

          case 4:
          case 'end':
            return _context13.stop();
        }
      }
    }, _callee13, undefined);
  })));

  it('should be able to use t decorator', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee14() {
    var translate, Test, wrapper;
    return _regenerator2.default.wrap(function _callee14$(_context14) {
      while (1) {
        switch (_context14.prev = _context14.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  test: 'Testovacia odpoved'
                }
              }
            });
            _context14.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            Test = function (_Component) {
              (0, _inherits3.default)(Test, _Component);

              function Test() {
                (0, _classCallCheck3.default)(this, Test);
                return (0, _possibleConstructorReturn3.default)(this, _Component.apply(this, arguments));
              }

              Test.prototype.render = function render() {
                return _react2.default.createElement(
                  'div',
                  null,
                  this.props.translate('test')
                );
              };

              return Test;
            }(_react.Component);

            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(
                _index.ProvideTranslate,
                null,
                function (t) {
                  return _react2.default.createElement(Test, { translate: t });
                }
              )
            ));


            expect(wrapper.html()).toBe('<div>Testovacia odpoved</div>');

          case 6:
          case 'end':
            return _context14.stop();
        }
      }
    }, _callee14, undefined);
  })));

  it('should be able to other components as props', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee15() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee15$(_context15) {
      while (1) {
        switch (_context15.prev = _context15.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  test: 'Testovacia odpoved {$link}'
                }
              }
            });
            _context15.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'test', link: _react2.default.createElement(
                  'a',
                  null,
                  'Asdf'
                ), html: true })
            ));


            expect(wrapper.html()).toBe('<span>Testovacia odpoved <a>Asdf</a></span>');

          case 5:
          case 'end':
            return _context15.stop();
        }
      }
    }, _callee15, undefined);
  })));

  it('should be able to other components as props with Translate', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee16() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee16$(_context16) {
      while (1) {
        switch (_context16.prev = _context16.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  test: 'Testovacia odpoved {$link}',
                  inner: '123'
                }
              }
            });
            _context16.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', translate: translate },
              _react2.default.createElement(_index2.default, { path: 'test', link: _react2.default.createElement(
                  'a',
                  null,
                  'Asdf ',
                  _react2.default.createElement(_index2.default, { path: 'inner' })
                ), html: true })
            ));


            expect(wrapper.html()).toBe('<span>Testovacia odpoved <a>Asdf 123</a></span>');

          case 5:
          case 'end':
            return _context16.stop();
        }
      }
    }, _callee16, undefined);
  })));

  it('should be able to use namespace', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee17() {
    var translate, wrapper;
    return _regenerator2.default.wrap(function _callee17$(_context17) {
      while (1) {
        switch (_context17.prev = _context17.next) {
          case 0:
            translate = new _translateMaker2.default({
              data: {
                sk_SK: {
                  namespace: {
                    test: 'Testovacia odpoved'
                  }
                }
              }
            });
            _context17.next = 3;
            return translate.setLocale('sk_SK');

          case 3:
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _index.LocaleProvider,
              { locale: 'sk_SK', namespace: 'namespace', translate: translate },
              _react2.default.createElement(
                _index.Namespace,
                { path: 'namespace' },
                _react2.default.createElement(_index2.default, { path: 'test', html: true })
              )
            ));


            expect(wrapper.html()).toBe('<span>Testovacia odpoved</span>');

          case 5:
          case 'end':
            return _context17.stop();
        }
      }
    }, _callee17, undefined);
  })));
});
//# sourceMappingURL=Translate.test.js.map