import _asyncToGenerator from 'babel-runtime/helpers/asyncToGenerator';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React, { Component, createContext } from 'react';
import Translate from 'translate-maker';

export const LocaleProviderContext = createContext({});

export default class LocaleProvider extends Component {

  constructor(props) {
    super(props);

    this.t = (path, attrs, defaultValue) => this.get(path, attrs, defaultValue);

    this.dataChanged = () => {
      this.forceUpdate();
    };

    this.localeChanged = () => {
      this.forceUpdate();
    };

    const {
      translate, locale, namespace, children, controlled } = props,
          rest = _objectWithoutProperties(props, ['translate', 'locale', 'namespace', 'children', 'controlled']);

    const instance = translate || new Translate(rest);

    this.state = {
      translate: instance
    };

    if (locale) {
      instance.setLocale(locale, namespace);
    }
  }

  componentDidMount() {
    const { translate } = this.state;

    translate.on('locale', this.localeChanged);
    translate.on('changed', this.dataChanged);
  }

  componentWillReceiveProps(newProps) {
    const { locale, namespace } = this.props;
    const { translate } = this.state;

    if (newProps.controlled) {
      if (newProps.locale !== locale) {
        translate.setLocale(newProps.locale, newProps.namespace);
      } else if (newProps.locale && newProps.namespace !== namespace) {
        translate.setLocale(newProps.locale, newProps.namespace);
      }
    }
  }

  componentWillUnmount() {
    const { translate } = this.state;

    translate.removeListener('locale', this.localeChanged);
    translate.removeListener('changed', this.dataChanged);
  }

  getLocale() {
    const { translate } = this.state;
    return translate.getLocale();
  }

  setLocale(locale) {
    var _this = this;

    return _asyncToGenerator(function* () {
      const { controlled } = _this.props;
      if (controlled) {
        throw new Error('LocaleProvider is set as controlled component. If you want to use setLocale please set controlled = false');
      }

      const { translate } = _this.state;
      yield translate.setLocale(locale);
    })();
  }

  get(path, attrs, defaultValue) {
    const { translate } = this.state;
    return translate.get(path, attrs, defaultValue);
  }

  set(path, value) {
    const { translate } = this.state;
    return translate.set(path, value);
  }

  render() {
    const { children } = this.props;

    return React.createElement(
      LocaleProviderContext.Provider,
      { value: { localeProvider: this } },
      children
    );
  }
}
LocaleProvider.defaultProps = {
  controlled: true
  /*
  locale: undefined,
  namespace: undefined,
  locales: undefined,
  cache: undefined,
  data: undefined,
  adapter: undefined,
  dotNotation: undefined,
  mode: undefined,
  references: undefined,
  variables: undefined,
  combinations: undefined,
  filters: undefined,
  translate: undefined,
  */
};
//# sourceMappingURL=LocaleProvider.js.map